django-celery-results - Celery Result Backends for Django — django_celery_results 1.0.0 documentation

# django-celery-results - Celery Result Backends for Django

Version: | 1.0.0
Web: | http://django-celery-results.readthedocs.org/
Download: | http://pypi.python.org/pypi/django-celery-results
Source: | http://github.com/celery/django-celery-results
Keywords: | KEYWORDS

## About

# I’m too lazy to edit the defaults.

## Contents

- Copyright

- API Reference
  - `django_celery_results.backends`
  - `django_celery_results.backends.database`
  - `django_celery_results.backends.cache`
  - `django_celery_results.models`
  - `django_celery_results.managers`
  - `django_celery_results.utils`

- Change history
- Glossary

## Indices and tables

- Index
- Module Index
- Search Page